@@ -30,13 +30,18 @@ phoenix_utils.setPath()
 
 args = phoenix_utils.shell_quote(sys.argv[1:])
 
-java_cmd = phoenix_utils.java + ' ' + phoenix_utils.jvm_module_flags + ' $PHOENIX_OPTS ' + \
+opts = os.getenv('PHOENIX_OPTS') or os.getenv('HBASE_OPTS') or ''
+
+java_cmd = phoenix_utils.java + ' ' + phoenix_utils.jvm_module_flags + \
+    ' ' + opts + \
     ' -cp "' + phoenix_utils.hbase_conf_dir + os.pathsep + phoenix_utils.hadoop_conf + \
     os.pathsep + phoenix_utils.slf4j_backend_jar + \
     os.pathsep + phoenix_utils.logging_jar + \
-    os.pathsep + phoenix_utils.phoenix_client_embedded_jar + '" -Dlog4j2.configurationFile=file:' + \
-    os.path.join(phoenix_utils.current_dir, "log4j2.properties") + \
-    " org.apache.phoenix.util.PhoenixRuntime " + args 
+    os.pathsep + phoenix_utils.phoenix_client_embedded_jar + \
+    '" -Djava.util.logging.config.class=org.apache.hadoop.hbase.logging.JulToSlf4jInitializer ' + \
+    ('' if '-Dlog4j2.configurationFile' in opts else ' -Dlog4j2.configurationFile=file:'
+        + os.path.join(phoenix_utils.current_dir, "log4j2.properties")) + \
+    " org.apache.phoenix.util.PhoenixRuntime " + args
 
 print(java_cmd)
 
