@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -17,10 +17,10 @@
  */
 package org.apache.phoenix.exception;
 
-
 public class UpgradeNotRequiredException extends RetriableUpgradeException {
-    public UpgradeNotRequiredException() {
-        super("Operation not allowed since cluster has already been upgraded. ", SQLExceptionCode.UPGRADE_NOT_REQUIRED
-                .getSQLState(), SQLExceptionCode.UPGRADE_NOT_REQUIRED.getErrorCode());
-    }
+  public UpgradeNotRequiredException() {
+    super("Operation not allowed since cluster has already been upgraded. ",
+      SQLExceptionCode.UPGRADE_NOT_REQUIRED.getSQLState(),
+      SQLExceptionCode.UPGRADE_NOT_REQUIRED.getErrorCode());
+  }
 }
