@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -19,8 +19,9 @@ package org.apache.phoenix.expression.function;
 
 public enum EncodeFormat {
 
-	HEX, //format for encoding HEX value to bytes
-	BASE62, //format for encoding a base 10 long value to base 62 string
-	BASE64, //format for encoding a base 10 long value to base 64 string
-	ASCII // Plain Text
+  HEX, // format for encoding HEX value to bytes
+  BASE62, // format for encoding a base 10 long value to base 62 string
+  BASE64, // format for encoding a base 10 long value to base 64 string
+  ASCII, // Plain Text
+  HBASE // HBase-specific escaping format
 };
