@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -21,12 +21,12 @@ import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
 
 public abstract class AbstractBasePattern {
 
-    public abstract void matches(ImmutableBytesWritable srcPtr);
+  public abstract void matches(ImmutableBytesWritable srcPtr);
 
-    public abstract void replaceAll(ImmutableBytesWritable srcPtr, byte[] rStrBytes,
-            int rStrOffset, int rStrLen);
+  public abstract void replaceAll(ImmutableBytesWritable srcPtr, byte[] rStrBytes, int rStrOffset,
+    int rStrLen);
 
-    public abstract void substr(ImmutableBytesWritable srcPtr, int offsetInStr);
+  public abstract void substr(ImmutableBytesWritable srcPtr, int offsetInStr);
 
-    public abstract String pattern();
+  public abstract String pattern();
 }
