@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -19,18 +19,12 @@ package org.apache.phoenix.expression.visitor;
 
 import org.apache.phoenix.expression.KeyValueColumnExpression;
 
-
-
-
 /**
- * 
- * Implementation of ExpressionVisitor where only KeyValueDataAccessor
- * is being visited
- *
- * 
+ * Implementation of ExpressionVisitor where only KeyValueDataAccessor is being visited
  * @since 0.1
  */
-public abstract class KeyValueExpressionVisitor extends StatelessTraverseAllExpressionVisitor<Void> {
-    @Override
-    abstract public Void visit(KeyValueColumnExpression node);
+public abstract class KeyValueExpressionVisitor
+  extends StatelessTraverseAllExpressionVisitor<Void> {
+  @Override
+  abstract public Void visit(KeyValueColumnExpression node);
 }
