@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,17 +18,18 @@
 package org.apache.phoenix.jdbc;
 
 import java.util.Map;
-
 import org.apache.phoenix.monitoring.MetricType;
 
 public interface PhoenixMetricsLog {
 
-    void logOverAllReadRequestMetrics(Map<MetricType, Long> overAllQueryMetrics, String sql);
+  void logOverAllReadRequestMetrics(Map<MetricType, Long> overAllQueryMetrics, String sql);
 
-    void logRequestReadMetrics(Map<String, Map<MetricType, Long>> requestReadMetrics, String sql);
+  void logRequestReadMetrics(Map<String, Map<MetricType, Long>> requestReadMetrics, String sql);
 
-    void logWriteMetricsfoForMutationsSinceLastReset(Map<String, Map<MetricType, Long>> mutationWriteMetrics);
+  void logWriteMetricsfoForMutationsSinceLastReset(
+    Map<String, Map<MetricType, Long>> mutationWriteMetrics);
 
-    void logReadMetricInfoForMutationsSinceLastReset(Map<String, Map<MetricType, Long>> mutationReadMetrics);
+  void logReadMetricInfoForMutationsSinceLastReset(
+    Map<String, Map<MetricType, Long>> mutationReadMetrics);
 
 }
