@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -15,7 +15,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.phoenix.jdbc;
 
 import java.sql.PreparedStatement;
@@ -23,6 +22,7 @@ import java.sql.PreparedStatement;
 /**
  * This interface is for phoenix statement that provide operation Type
  */
-public interface PhoenixMonitoredPreparedStatement extends PreparedStatement, PhoenixMonitoredStatement {
+public interface PhoenixMonitoredPreparedStatement
+  extends PreparedStatement, PhoenixMonitoredStatement {
 
 }
