@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,5 +18,7 @@
 package org.apache.phoenix.log;
 
 public enum QueryStatus {
-    COMPILED, COMPLETED,FAILED 
+  COMPILED,
+  COMPLETED,
+  FAILED
 }
