@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -15,29 +15,29 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.phoenix.parse;
 
 import org.apache.phoenix.util.SchemaUtil;
 
 public class PropertyName {
-    private final NamedNode familyName;
-    private final String propertyName;
-    
-    PropertyName(String familyName, String propertyName) {
-        this.familyName = familyName == null ? null : new NamedNode(familyName);
-        this.propertyName = SchemaUtil.normalizeIdentifier(propertyName);;
-    }
+  private final NamedNode familyName;
+  private final String propertyName;
 
-    PropertyName(String columnName) {
-        this(null, columnName);
-    }
+  PropertyName(String familyName, String propertyName) {
+    this.familyName = familyName == null ? null : new NamedNode(familyName);
+    this.propertyName = SchemaUtil.normalizeIdentifier(propertyName);
+    ;
+  }
 
-    public String getFamilyName() {
-        return familyName == null ? "" : familyName.getName();
-    }
+  PropertyName(String columnName) {
+    this(null, columnName);
+  }
 
-    public String getPropertyName() {
-        return propertyName;
-    }
-}
\ No newline at end of file
+  public String getFamilyName() {
+    return familyName == null ? "" : familyName.getName();
+  }
+
+  public String getPropertyName() {
+    return propertyName;
+  }
+}
