@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -15,7 +15,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.phoenix.parse;
 
 import org.apache.phoenix.jdbc.PhoenixStatement;
@@ -24,15 +23,16 @@ import org.apache.phoenix.jdbc.PhoenixStatement;
  * Parent class for SHOW CREATE TABLE statements.
  */
 public class ShowCreateTable implements BindableStatement {
-    @Override
-    public int getBindCount() {
-        return 0;
-    }
+  @Override
+  public int getBindCount() {
+    return 0;
+  }
 
-    @Override
-    public PhoenixStatement.Operation getOperation() {
-        return PhoenixStatement.Operation.QUERY;
-    }
+  @Override
+  public PhoenixStatement.Operation getOperation() {
+    return PhoenixStatement.Operation.QUERY;
+  }
 
-    public ShowCreateTable() {}
+  public ShowCreateTable() {
+  }
 }
