@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -21,15 +21,20 @@ import java.util.Collections;
 import java.util.List;
 
 /**
- * 
  * Abstract node for expressions that have no children
- *
- * 
  * @since 0.1
  */
 public abstract class TerminalParseNode extends ParseNode {
-    @Override
-    public final List<ParseNode> getChildren() {
-        return Collections.emptyList();
-    }
+  @Override
+  public final List<ParseNode> getChildren() {
+    return Collections.emptyList();
+  }
+
+  public boolean isWildcardNode() {
+    return false;
+  }
+
+  public TerminalParseNode getRewritten() {
+    return null;
+  }
 }
