@@ -1,12 +1,13 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to you under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -26,10 +27,12 @@ public class PropertyNotAllowedException extends SQLException {
   private static final long serialVersionUID = 1L;
   private final Properties offendingProperties;
 
-  public PropertyNotAllowedException(Properties offendingProperties){
-    this.offendingProperties=offendingProperties;
+  public PropertyNotAllowedException(Properties offendingProperties) {
+    this.offendingProperties = offendingProperties;
   }
 
-  public Properties getOffendingProperties(){ return this.offendingProperties; }
+  public Properties getOffendingProperties() {
+    return this.offendingProperties;
+  }
 
 }
