@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -15,27 +15,23 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.phoenix.schema.export;
 
+import java.io.IOException;
 import org.apache.hadoop.conf.Configuration;
 
-import java.io.IOException;
-
 public class SchemaWriterFactory {
-    public static SchemaWriter getSchemaWriter(Configuration conf)
-            throws IOException {
-        try {
-            String className = conf.get(SchemaRegistryRepository.SCHEMA_WRITER_IMPL_KEY);
-            if (className == null) {
-                return new DefaultSchemaWriter();
-            }
-            Class<SchemaWriter> clazz =
-                    (Class<SchemaWriter>) Class.forName(className);
-            return clazz.newInstance();
-        } catch (ClassNotFoundException | InstantiationException | IllegalAccessException |
-                ClassCastException e) {
-            throw new IOException(e);
-        }
+  public static SchemaWriter getSchemaWriter(Configuration conf) throws IOException {
+    try {
+      String className = conf.get(SchemaRegistryRepository.SCHEMA_WRITER_IMPL_KEY);
+      if (className == null) {
+        return new DefaultSchemaWriter();
+      }
+      Class<SchemaWriter> clazz = (Class<SchemaWriter>) Class.forName(className);
+      return clazz.newInstance();
+    } catch (ClassNotFoundException | InstantiationException | IllegalAccessException
+      | ClassCastException e) {
+      throw new IOException(e);
     }
+  }
 }
