@@ -4,12 +4,12 @@
  * distributed with this work for additional information
  * regarding copyright ownership.  The ASF licenses this file
  * to you under the Apache License, Version 2.0 (the
- * "License"); you maynot use this file except in compliance
+ * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicablelaw or agreed to in writing, software
+ * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
@@ -18,9 +18,11 @@
 package org.apache.phoenix.schema.stats;
 
 public enum StatisticsCollectionScope {
-    COLUMNS, INDEX, ALL;
+  COLUMNS,
+  INDEX,
+  ALL;
 
-    public static StatisticsCollectionScope getDefault() {
-        return ALL;
-    }
+  public static StatisticsCollectionScope getDefault() {
+    return ALL;
+  }
 }
