@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -15,25 +15,28 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.phoenix.iterate;
 
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Properties;
 import java.util.concurrent.ConcurrentMap;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.ExtendedCellBuilder;
+import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.ServerName;
+import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.AbstractClientScanner;
 import org.apache.hadoop.hbase.client.Connection;
 import org.apache.hadoop.hbase.client.IsolationLevel;
 import org.apache.hadoop.hbase.client.RegionInfo;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.Scan;
+import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessor;
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
@@ -41,14 +44,11 @@ import org.apache.hadoop.hbase.io.hfile.BlockCacheFactory;
 import org.apache.hadoop.hbase.metrics.MetricRegistry;
 import org.apache.hadoop.hbase.mob.MobFileCache;
 import org.apache.hadoop.hbase.regionserver.HRegion;
+import org.apache.hadoop.hbase.regionserver.MemStoreLAB;
 import org.apache.hadoop.hbase.regionserver.OnlineRegions;
 import org.apache.hadoop.hbase.regionserver.Region;
 import org.apache.hadoop.hbase.regionserver.RegionScanner;
 import org.apache.hadoop.hbase.util.CommonFSUtils;
-import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.TableName;
-import org.apache.hadoop.hbase.client.Table;
-import org.apache.hadoop.hbase.regionserver.MemStoreLAB;
 import org.apache.phoenix.coprocessorclient.BaseScannerRegionObserverConstants;
 import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.apache.phoenix.jdbc.PhoenixDatabaseMetaData;
@@ -62,8 +62,6 @@ import org.apache.phoenix.util.SchemaUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import java.util.Properties;
-
 /**
  * Scan over a region from restored snapshot
  */
@@ -76,8 +74,8 @@ public class SnapshotScanner extends AbstractClientScanner {
   private List<Cell> values;
   private StatisticsCollector statisticsCollector;
 
-  public SnapshotScanner(Configuration conf, FileSystem fs, Path rootDir,
-      TableDescriptor htd, RegionInfo hri,  Scan scan) throws Throwable{
+  public SnapshotScanner(Configuration conf, FileSystem fs, Path rootDir, TableDescriptor htd,
+    RegionInfo hri, Scan scan) throws Throwable {
 
     LOGGER.info("Creating SnapshotScanner for region: " + hri);
 
@@ -95,20 +93,24 @@ public class SnapshotScanner extends AbstractClientScanner {
     // Collect statistics during scan if ANALYZE_TABLE attribute is set
     if (ScanUtil.isAnalyzeTable(scan)) {
       this.scanner = region.getScanner(scan);
-      PhoenixConnection connection = (PhoenixConnection) ConnectionUtil.getInputConnection(conf, new Properties());
+      PhoenixConnection connection =
+        (PhoenixConnection) ConnectionUtil.getInputConnection(conf, new Properties());
       String tableName = region.getTableDescriptor().getTableName().getNameAsString();
-      TableName physicalTableName = SchemaUtil.getPhysicalTableName(PhoenixDatabaseMetaData.SYSTEM_CATALOG_NAME_BYTES, conf);
+      TableName physicalTableName =
+        SchemaUtil.getPhysicalTableName(PhoenixDatabaseMetaData.SYSTEM_CATALOG_NAME_BYTES, conf);
       Table table = connection.getQueryServices().getTable(physicalTableName.getName());
-      StatisticsWriter statsWriter = StatisticsWriter.newWriter(connection, tableName, HConstants.LATEST_TIMESTAMP);
-      statisticsCollector = new DefaultStatisticsCollector(conf, region,
-              tableName, null, null, null, statsWriter, table);
+      StatisticsWriter statsWriter =
+        StatisticsWriter.newWriter(connection, tableName, HConstants.LATEST_TIMESTAMP);
+      statisticsCollector = new DefaultStatisticsCollector(conf, region, tableName, null, null,
+        null, statsWriter, table);
     } else if (scan.getAttribute(BaseScannerRegionObserverConstants.NON_AGGREGATE_QUERY) != null) {
       RegionScannerFactory regionScannerFactory = new NonAggregateRegionScannerFactory(snapshotEnv);
       this.scanner = regionScannerFactory.getRegionScanner(scan, region.getScanner(scan));
       statisticsCollector = new NoOpStatisticsCollector();
     } else {
-      /* future work : Snapshot M/R jobs for aggregate queries*/
-      throw new UnsupportedOperationException("Snapshot M/R jobs not available for aggregate queries");
+      /* future work : Snapshot M/R jobs for aggregate queries */
+      throw new UnsupportedOperationException(
+        "Snapshot M/R jobs not available for aggregate queries");
     }
 
     statisticsCollector.init();
@@ -119,19 +121,17 @@ public class SnapshotScanner extends AbstractClientScanner {
    * Initialize region for snapshot scanner utility. This is client side region initialization and
    * hence it should follow the same region init pattern as the one used by hbase
    * ClientSideRegionScanner.
-   *
-   * @param conf The configuration.
-   * @param fs The filesystem instance.
+   * @param conf    The configuration.
+   * @param fs      The filesystem instance.
    * @param rootDir Restored region root dir.
-   * @param htd The table descriptor instance used to retrieve the region root dir.
-   * @param hri The region info.
+   * @param htd     The table descriptor instance used to retrieve the region root dir.
+   * @param hri     The region info.
    * @throws IOException If region init throws IOException.
    */
   private void initRegionForSnapshotScanner(Configuration conf, FileSystem fs, Path rootDir,
-                                            TableDescriptor htd,
-                                            RegionInfo hri) throws IOException {
+    TableDescriptor htd, RegionInfo hri) throws IOException {
     region = HRegion.newHRegion(CommonFSUtils.getTableDir(rootDir, htd.getTableName()), null, fs,
-            conf, hri, htd, null);
+      conf, hri, htd, null);
     region.setRestoredRegion(true);
     // non RS process does not have a block cache, and this a client side scanner,
     // create one for MapReduce jobs to cache the INDEX block by setting to use
@@ -140,12 +140,11 @@ public class SnapshotScanner extends AbstractClientScanner {
     // HConstants.HFILE_ONHEAP_BLOCK_CACHE_FIXED_SIZE_KEY is only available from 2.4.6
     // We are using the string directly here to let Phoenix compile with earlier versions.
     // Note that it won't do anything before HBase 2.4.6
-    conf.setIfUnset("hfile.onheap.block.cache.fixed.size",
-            String.valueOf(32 * 1024 * 1024L));
+    conf.setIfUnset("hfile.onheap.block.cache.fixed.size", String.valueOf(32 * 1024 * 1024L));
     // don't allow L2 bucket cache for non RS process to avoid unexpected disk usage.
     conf.unset(HConstants.BUCKET_CACHE_IOENGINE_KEY);
-    //PHOENIX-7367 - non RS process doesn't have MemstoreLab's ChunkCreator initialized
-    //so we disable it to avoid NPE while closing the memstore as part of region close
+    // PHOENIX-7367 - non RS process doesn't have MemstoreLab's ChunkCreator initialized
+    // so we disable it to avoid NPE while closing the memstore as part of region close
     conf.setBoolean(MemStoreLAB.USEMSLAB_KEY, false);
     region.setBlockCache(BlockCacheFactory.createBlockCache(conf));
     // we won't initialize the MobFileCache when not running in RS process. so provided an
@@ -156,7 +155,6 @@ public class SnapshotScanner extends AbstractClientScanner {
     region.initialize();
   }
 
-
   @Override
   public Result next() throws IOException {
     values.clear();
@@ -165,7 +163,7 @@ public class SnapshotScanner extends AbstractClientScanner {
     if (hasMore || !values.isEmpty()) {
       return Result.create(values);
     } else {
-      //we are done
+      // we are done
       return null;
     }
   }
@@ -244,40 +242,40 @@ public class SnapshotScanner extends AbstractClientScanner {
         throw new UnsupportedOperationException();
       }
 
-    @Override
-    public RegionCoprocessor getInstance() {
+      @Override
+      public RegionCoprocessor getInstance() {
         throw new UnsupportedOperationException();
-    }
+      }
 
-    @Override
-    public OnlineRegions getOnlineRegions() {
+      @Override
+      public OnlineRegions getOnlineRegions() {
         throw new UnsupportedOperationException();
-    }
+      }
 
-    @Override
-    public ServerName getServerName() {
+      @Override
+      public ServerName getServerName() {
         throw new UnsupportedOperationException();
-    }
+      }
 
-    @Override
-    public Connection getConnection() {
+      @Override
+      public Connection getConnection() {
         throw new UnsupportedOperationException();
-    }
+      }
 
-    @Override
-    public MetricRegistry getMetricRegistryForRegionServer() {
+      @Override
+      public MetricRegistry getMetricRegistryForRegionServer() {
         throw new UnsupportedOperationException();
-    }
+      }
 
-    @Override
-    public Connection createConnection(Configuration conf) throws IOException {
+      @Override
+      public Connection createConnection(Configuration conf) throws IOException {
         throw new UnsupportedOperationException();
-    }
+      }
 
-    @Override
-    public ExtendedCellBuilder getCellBuilder() {
+      @Override
+      public ExtendedCellBuilder getCellBuilder() {
         throw new UnsupportedOperationException();
-    }
+      }
     };
   }
 }
