@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -28,30 +28,29 @@ import java.sql.DriverManager;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.util.Properties;
-
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
 
-
 @Category(ParallelStatsDisabledTest.class)
 public class QueryExecWithoutSCNIT extends ParallelStatsDisabledIT {
-    @Test
-    public void testScanNoSCN() throws Exception {
-        String tenantId = getOrganizationId();
-        String tableName = initATableValues(tenantId, getDefaultSplits(tenantId), null, null, getUrl());
-        String query = "SELECT a_string, b_string FROM " + tableName + " WHERE organization_id=? and a_integer = 5";
-        Properties props = new Properties(); // Test with no CurrentSCN property set
-        Connection conn = DriverManager.getConnection(getUrl(), props);
-        try {
-            PreparedStatement statement = conn.prepareStatement(query);
-            statement.setString(1, tenantId);
-            ResultSet rs = statement.executeQuery();
-            assertTrue (rs.next());
-            assertEquals(rs.getString(1), B_VALUE);
-            assertEquals(rs.getString("B_string"), C_VALUE);
-            assertFalse(rs.next());
-        } finally {
-            conn.close();
-        }
+  @Test
+  public void testScanNoSCN() throws Exception {
+    String tenantId = getOrganizationId();
+    String tableName = initATableValues(tenantId, getDefaultSplits(tenantId), null, null, getUrl());
+    String query =
+      "SELECT a_string, b_string FROM " + tableName + " WHERE organization_id=? and a_integer = 5";
+    Properties props = new Properties(); // Test with no CurrentSCN property set
+    Connection conn = DriverManager.getConnection(getUrl(), props);
+    try {
+      PreparedStatement statement = conn.prepareStatement(query);
+      statement.setString(1, tenantId);
+      ResultSet rs = statement.executeQuery();
+      assertTrue(rs.next());
+      assertEquals(rs.getString(1), B_VALUE);
+      assertEquals(rs.getString("B_string"), C_VALUE);
+      assertFalse(rs.next());
+    } finally {
+      conn.close();
     }
+  }
 }
