@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -19,18 +19,18 @@ package org.apache.phoenix.end2end;
 
 import java.util.Arrays;
 import java.util.Collection;
-
 import org.junit.experimental.categories.Category;
 import org.junit.runners.Parameterized.Parameters;
 
-@Category(ParallelStatsDisabledTest.class)
+@Category(NeedsOwnMiniClusterTest.class)
 public class SetPropertyOnNonEncodedTableIT extends SetPropertyIT {
-    public SetPropertyOnNonEncodedTableIT(boolean columnEncoded) {
-        super(columnEncoded);
-    }
+  public SetPropertyOnNonEncodedTableIT(boolean columnEncoded) {
+    super(columnEncoded);
+  }
 
-    @Parameters(name="SetPropertyOnNonEncodedTableIT") // name is used by failsafe as file name in reports
-    public static synchronized Collection<Boolean> data() {
-        return Arrays.asList( false );
-    }
+  @Parameters(name = "SetPropertyOnNonEncodedTableIT") // name is used by failsafe as file name in
+                                                       // reports
+  public static synchronized Collection<Boolean> data() {
+    return Arrays.asList(false);
+  }
 }
