@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -15,7 +15,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.phoenix.end2end;
 
 import static org.junit.Assert.assertEquals;
@@ -40,8 +39,6 @@ import java.util.Map;
 import java.util.Properties;
 import java.util.Random;
 import java.util.UUID;
-
-import org.apache.commons.collections.CollectionUtils;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileStatus;
 import org.apache.hadoop.fs.FileSystem;
@@ -69,7 +66,6 @@ import org.apache.phoenix.mapreduce.util.PhoenixMapReduceUtil;
 import org.apache.phoenix.query.BaseTest;
 import org.apache.phoenix.schema.types.PDouble;
 import org.apache.phoenix.schema.types.PhoenixArray;
-import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 import org.apache.phoenix.util.ReadOnlyProps;
 import org.junit.Assert;
 import org.junit.Before;
@@ -81,6 +77,8 @@ import org.junit.runners.Parameterized;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
+
 @Category(NeedsOwnMiniClusterTest.class)
 @RunWith(Parameterized.class)
 public class TableSnapshotReadsMapReduceIT extends BaseTest {
@@ -95,17 +93,16 @@ public class TableSnapshotReadsMapReduceIT extends BaseTest {
   private static final String FIELD1 = "FIELD1";
   private static final String FIELD2 = "FIELD2";
   private static final String FIELD3 = "FIELD3";
-  private static final String CREATE_TABLE = "CREATE TABLE IF NOT EXISTS %s ( " +
-      " FIELD1 VARCHAR NOT NULL , FIELD2 VARCHAR , FIELD3 INTEGER CONSTRAINT pk PRIMARY KEY (FIELD1 ))";
+  private static final String CREATE_TABLE = "CREATE TABLE IF NOT EXISTS %s ( "
+    + " FIELD1 VARCHAR NOT NULL , FIELD2 VARCHAR , FIELD3 INTEGER CONSTRAINT pk PRIMARY KEY (FIELD1 ))";
   private static final String UPSERT = "UPSERT into %s values (?, ?, ?)";
-  private static final String CREATE_STOCK_TABLE =
-          "CREATE TABLE IF NOT EXISTS %s ( " + STOCK_NAME + " VARCHAR NOT NULL , " + RECORDING_YEAR
-                  + "  INTEGER NOT  NULL,  " + RECORDINGS_QUARTER + " "
-                  + " DOUBLE array[] CONSTRAINT pk PRIMARY KEY ( " + STOCK_NAME + ", "
-                  + RECORDING_YEAR + " )) " + "SPLIT ON ('AA')";
+  private static final String CREATE_STOCK_TABLE = "CREATE TABLE IF NOT EXISTS %s ( " + STOCK_NAME
+    + " VARCHAR NOT NULL , " + RECORDING_YEAR + "  INTEGER NOT  NULL,  " + RECORDINGS_QUARTER + " "
+    + " DOUBLE array[] CONSTRAINT pk PRIMARY KEY ( " + STOCK_NAME + ", " + RECORDING_YEAR + " )) "
+    + "SPLIT ON ('AA')";
   private static final String CREATE_STOCK_STATS_TABLE =
-          "CREATE TABLE IF NOT EXISTS %s(" + STOCK_NAME + " VARCHAR NOT NULL , " + MAX_RECORDING
-                  + " DOUBLE CONSTRAINT pk PRIMARY KEY (" + STOCK_NAME + " ))";
+    "CREATE TABLE IF NOT EXISTS %s(" + STOCK_NAME + " VARCHAR NOT NULL , " + MAX_RECORDING
+      + " DOUBLE CONSTRAINT pk PRIMARY KEY (" + STOCK_NAME + " ))";
   private static List<List<Object>> result;
   private long timestamp;
   private String tableName;
@@ -126,9 +123,9 @@ public class TableSnapshotReadsMapReduceIT extends BaseTest {
 
   @BeforeClass
   public static synchronized void doSetup() throws Exception {
-      Map<String,String> props = Maps.newHashMapWithExpectedSize(1);
-      setUpTestDriver(new ReadOnlyProps(props.entrySet().iterator()));
-      getUtility().getAdmin().balancerSwitch(false, true);
+    Map<String, String> props = Maps.newHashMapWithExpectedSize(1);
+    setUpTestDriver(new ReadOnlyProps(props.entrySet().iterator()));
+    getUtility().getAdmin().balancerSwitch(false, true);
   }
 
   @Before
@@ -147,46 +144,45 @@ public class TableSnapshotReadsMapReduceIT extends BaseTest {
 
   @Test
   public void testMapReduceSnapshots() throws Exception {
-    PhoenixMapReduceUtil.setInput(job,PhoenixIndexDBWritable.class,
-            SNAPSHOT_NAME, tableName, tmpDir, null, FIELD1, FIELD2, FIELD3);
+    PhoenixMapReduceUtil.setInput(job, PhoenixIndexDBWritable.class, SNAPSHOT_NAME, tableName,
+      tmpDir, null, FIELD1, FIELD2, FIELD3);
     configureJob(job, tableName, null, null, false);
   }
 
   @Test
   public void testMapReduceSnapshotsMultiRegion() throws Exception {
     String inputQuery = "SELECT * FROM " + tableName + " ORDER BY FIELD1 asc";
-    PhoenixMapReduceUtil.setInput(job,PhoenixIndexDBWritable.class,
-            SNAPSHOT_NAME, tableName, tmpDir, inputQuery);
+    PhoenixMapReduceUtil.setInput(job, PhoenixIndexDBWritable.class, SNAPSHOT_NAME, tableName,
+      tmpDir, inputQuery);
     configureJob(job, tableName, null, null, true);
   }
 
   @Test
   public void testMapReduceSnapshotsWithCondition() throws Exception {
-    PhoenixMapReduceUtil.setInput(job,PhoenixIndexDBWritable.class,
-            SNAPSHOT_NAME, tableName, tmpDir, FIELD3 + " > 0001", FIELD1, FIELD2, FIELD3);
+    PhoenixMapReduceUtil.setInput(job, PhoenixIndexDBWritable.class, SNAPSHOT_NAME, tableName,
+      tmpDir, FIELD3 + " > 0001", FIELD1, FIELD2, FIELD3);
     configureJob(job, tableName, null, "FIELD3 > 0001", false);
   }
 
   @Test
   public void testMapReduceSnapshotWithLimit() throws Exception {
     String inputQuery = "SELECT * FROM " + tableName + " ORDER BY FIELD2 LIMIT 1";
-    PhoenixMapReduceUtil.setInput(job,PhoenixIndexDBWritable.class,
-            SNAPSHOT_NAME, tableName, tmpDir, inputQuery);
+    PhoenixMapReduceUtil.setInput(job, PhoenixIndexDBWritable.class, SNAPSHOT_NAME, tableName,
+      tmpDir, inputQuery);
     configureJob(job, tableName, inputQuery, null, false);
   }
 
   @Test
   public void testSnapshotMapReduceJobNotImpactingTableMapReduceJob() throws Exception {
-    //Submitting and asserting successful Map Reduce Job over snapshots
-    PhoenixMapReduceUtil
-            .setInput(job, PhoenixIndexDBWritable.class, SNAPSHOT_NAME, tableName, tmpDir, null,
-                    FIELD1, FIELD2, FIELD3);
+    // Submitting and asserting successful Map Reduce Job over snapshots
+    PhoenixMapReduceUtil.setInput(job, PhoenixIndexDBWritable.class, SNAPSHOT_NAME, tableName,
+      tmpDir, null, FIELD1, FIELD2, FIELD3);
     configureJob(job, tableName, null, null, false);
 
-    //Asserting that snapshot name is set in configuration
+    // Asserting that snapshot name is set in configuration
     Configuration config = job.getConfiguration();
     Assert.assertEquals("Correct snapshot name not found in configuration", SNAPSHOT_NAME,
-            config.get(PhoenixConfigurationUtil.SNAPSHOT_NAME_KEY));
+      config.get(PhoenixConfigurationUtil.SNAPSHOT_NAME_KEY));
 
     TestingMapReduceParallelScanGrouper.clearNumCallsToGetRegionBoundaries();
 
@@ -196,19 +192,19 @@ public class TableSnapshotReadsMapReduceIT extends BaseTest {
       conn.createStatement().execute(String.format(CREATE_TABLE, tableName));
       conn.commit();
 
-      //Submitting next map reduce job over table and making sure that it does not fail with
+      // Submitting next map reduce job over table and making sure that it does not fail with
       // any wrong snapshot properties set in common configurations which are
       // used across all jobs.
       job = createAndTestJob(conn);
     }
-    //Asserting that snapshot name is no more set in common shared configuration
+    // Asserting that snapshot name is no more set in common shared configuration
     config = job.getConfiguration();
     Assert.assertNull("Snapshot name is not null in Configuration",
-            config.get(PhoenixConfigurationUtil.SNAPSHOT_NAME_KEY));
+      config.get(PhoenixConfigurationUtil.SNAPSHOT_NAME_KEY));
   }
 
   private Job createAndTestJob(Connection conn)
-          throws SQLException, IOException, InterruptedException, ClassNotFoundException {
+    throws SQLException, IOException, InterruptedException, ClassNotFoundException {
     String stockTableName = generateUniqueName();
     String stockStatsTableName = generateUniqueName();
     conn.createStatement().execute(String.format(CREATE_STOCK_TABLE, stockTableName));
@@ -216,19 +212,21 @@ public class TableSnapshotReadsMapReduceIT extends BaseTest {
     conn.commit();
     final Configuration conf = ((PhoenixConnection) conn).getQueryServices().getConfiguration();
     Job job = Job.getInstance(conf);
-    PhoenixMapReduceUtil.setInput(job, MapReduceIT.StockWritable.class, PhoenixTestingInputFormat.class,
-            stockTableName, null, STOCK_NAME, RECORDING_YEAR, "0." + RECORDINGS_QUARTER);
+    PhoenixMapReduceUtil.setInput(job, MapReduceIT.StockWritable.class,
+      PhoenixTestingInputFormat.class, stockTableName, null, STOCK_NAME, RECORDING_YEAR,
+      "0." + RECORDINGS_QUARTER);
     testJob(conn, job, stockTableName, stockStatsTableName);
     return job;
   }
 
   private void testJob(Connection conn, Job job, String stockTableName, String stockStatsTableName)
-          throws SQLException, InterruptedException, IOException, ClassNotFoundException {
+    throws SQLException, InterruptedException, IOException, ClassNotFoundException {
     assertEquals("Failed to reset getRegionBoundaries counter for scanGrouper", 0,
-            TestingMapReduceParallelScanGrouper.getNumCallsToGetRegionBoundaries());
+      TestingMapReduceParallelScanGrouper.getNumCallsToGetRegionBoundaries());
     upsertData(conn, stockTableName);
 
-    // only run locally, rather than having to spin up a MiniMapReduce cluster and lets us use breakpoints
+    // only run locally, rather than having to spin up a MiniMapReduce cluster and lets us use
+    // breakpoints
     job.getConfiguration().set("mapreduce.framework.name", "local");
 
     setOutput(job, stockStatsTableName);
@@ -243,23 +241,24 @@ public class TableSnapshotReadsMapReduceIT extends BaseTest {
     job.setOutputValueClass(MapReduceIT.StockWritable.class);
 
     // run job and assert if success
-    assertTrue("Job didn't complete successfully! Check logs for reason.", job.waitForCompletion(true));
+    assertTrue("Job didn't complete successfully! Check logs for reason.",
+      job.waitForCompletion(true));
   }
 
   /**
    * Custom output setting because output upsert statement setting is broken (PHOENIX-2677)
-   *
    * @param job to update
    */
   private void setOutput(Job job, String stockStatsTableName) {
     final Configuration configuration = job.getConfiguration();
     PhoenixConfigurationUtil.setOutputTableName(configuration, stockStatsTableName);
-    configuration.set(PhoenixConfigurationUtil.UPSERT_STATEMENT, "UPSERT into " + stockStatsTableName +
-            " (" + STOCK_NAME + ", " + MAX_RECORDING + ") values (?,?)");
+    configuration.set(PhoenixConfigurationUtil.UPSERT_STATEMENT, "UPSERT into "
+      + stockStatsTableName + " (" + STOCK_NAME + ", " + MAX_RECORDING + ") values (?,?)");
     job.setOutputFormatClass(PhoenixOutputFormat.class);
   }
 
-  private void configureJob(Job job, String tableName, String inputQuery, String condition, boolean shouldSplit) throws Exception {
+  private void configureJob(Job job, String tableName, String inputQuery, String condition,
+    boolean shouldSplit) throws Exception {
     try {
       upsertAndSnapshot(tableName, shouldSplit, job.getConfiguration());
       result = new ArrayList<>();
@@ -280,18 +279,18 @@ public class TableSnapshotReadsMapReduceIT extends BaseTest {
         selectQuery.append(" WHERE " + condition);
       }
 
-      if (inputQuery == null)
-        inputQuery = selectQuery.toString();
+      if (inputQuery == null) inputQuery = selectQuery.toString();
 
-      ResultSet rs = DriverManager.getConnection(getUrl(), props).createStatement().executeQuery(inputQuery);
+      ResultSet rs =
+        DriverManager.getConnection(getUrl(), props).createStatement().executeQuery(inputQuery);
 
-      if(shouldSplit) {
-        //Records may not be processed in the same order as the query runs,
-        //make sure everything is ordered by Field1 ASC
-        Collections.sort(result, new Comparator<List<Object>>(){
+      if (shouldSplit) {
+        // Records may not be processed in the same order as the query runs,
+        // make sure everything is ordered by Field1 ASC
+        Collections.sort(result, new Comparator<List<Object>>() {
           @Override
           public int compare(List<Object> o1, List<Object> o2) {
-              return ((String)o1.get(0)).compareTo((String)o2.get(0));
+            return ((String) o1.get(0)).compareTo((String) o2.get(0));
           }
         });
       }
@@ -307,7 +306,9 @@ public class TableSnapshotReadsMapReduceIT extends BaseTest {
         assertEquals("Got the incorrect value for field3", r.get(i++), field3);
       }
 
-      assertFalse("Should only have stored" + result.size() + "rows in the table for the timestamp!", rs.next());
+      assertFalse(
+        "Should only have stored" + result.size() + "rows in the table for the timestamp!",
+        rs.next());
       assertRestoreDirCount(conf, tmpDir.toString(), 1);
     } finally {
       deleteSnapshotIfExists(SNAPSHOT_NAME);
@@ -316,12 +317,13 @@ public class TableSnapshotReadsMapReduceIT extends BaseTest {
 
   private void upsertData(Connection conn, String stockTableName) throws SQLException {
     PreparedStatement stmt = conn.prepareStatement(String.format(UPSERT, stockTableName));
-    upsertRecord(stmt, "AAPL", 2009, new Double[]{85.88, 91.04, 88.5, 90.3});
-    upsertRecord(stmt, "AAPL", 2008, new Double[]{75.88, 81.04, 78.5, 80.3});
+    upsertRecord(stmt, "AAPL", 2009, new Double[] { 85.88, 91.04, 88.5, 90.3 });
+    upsertRecord(stmt, "AAPL", 2008, new Double[] { 75.88, 81.04, 78.5, 80.3 });
     conn.commit();
   }
 
-  private void upsertRecord(PreparedStatement stmt, String name, int year, Double[] data) throws SQLException {
+  private void upsertRecord(PreparedStatement stmt, String name, int year, Double[] data)
+    throws SQLException {
     int i = 1;
     stmt.setString(i++, name);
     stmt.setInt(i++, year);
@@ -362,14 +364,16 @@ public class TableSnapshotReadsMapReduceIT extends BaseTest {
     conn.commit();
   }
 
-  private void upsertRecord(PreparedStatement stmt, String field1, String field2, int field3) throws SQLException {
+  private void upsertRecord(PreparedStatement stmt, String field1, String field2, int field3)
+    throws SQLException {
     stmt.setString(1, field1);
     stmt.setString(2, field2);
     stmt.setInt(3, field3);
     stmt.execute();
   }
 
-  private void upsertAndSnapshot(String tableName, boolean shouldSplit, Configuration configuration) throws Exception {
+  private void upsertAndSnapshot(String tableName, boolean shouldSplit, Configuration configuration)
+    throws Exception {
     if (shouldSplit) {
       // having very few rows in table doesn't really help much with splitting case.
       // we should upsert large no of rows as a prerequisite to splitting
@@ -380,7 +384,7 @@ public class TableSnapshotReadsMapReduceIT extends BaseTest {
 
     TableName hbaseTableName = TableName.valueOf(tableName);
     try (Connection conn = DriverManager.getConnection(getUrl());
-         Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()) {
+      Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()) {
 
       if (shouldSplit) {
         splitTableSync(admin, hbaseTableName, Bytes.toBytes("CCCC"), 2);
@@ -400,21 +404,21 @@ public class TableSnapshotReadsMapReduceIT extends BaseTest {
       upsertRecord(stmt, "DDDD", "SNFB", 45);
       conn.commit();
       if (isSnapshotRestoreDoneExternally) {
-        //Performing snapshot restore which will be used during scans
+        // Performing snapshot restore which will be used during scans
         Path rootDir = new Path(configuration.get(HConstants.HBASE_DIR));
         FileSystem fs = rootDir.getFileSystem(configuration);
         Path restoreDir = new Path(configuration.get(PhoenixConfigurationUtil.RESTORE_DIR_KEY));
-        RestoreSnapshotHelper.copySnapshotForScanner(configuration, fs, rootDir, restoreDir, SNAPSHOT_NAME);
+        RestoreSnapshotHelper.copySnapshotForScanner(configuration, fs, rootDir, restoreDir,
+          SNAPSHOT_NAME);
         PhoenixConfigurationUtil.setMRSnapshotManagedExternally(configuration, true);
       }
     }
   }
 
-  private void snapshotCreateSync(TableName hbaseTableName,
-      Admin admin, String snapshotName) throws IOException, InterruptedException {
+  private void snapshotCreateSync(TableName hbaseTableName, Admin admin, String snapshotName)
+    throws IOException, InterruptedException {
     boolean isSnapshotCreated = false;
-    SnapshotDescription snapshotDescription =
-      new SnapshotDescription(snapshotName);
+    SnapshotDescription snapshotDescription = new SnapshotDescription(snapshotName);
     // 3 retries while creating snapshot. if all 3 retries exhausted, we have
     // some valid issue.
     for (int i = 0; i < 3; i++) {
@@ -451,10 +455,10 @@ public class TableSnapshotReadsMapReduceIT extends BaseTest {
 
   private void deleteSnapshotIfExists(String snapshotName) throws Exception {
     try (Connection conn = DriverManager.getConnection(getUrl());
-         Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()) {
+      Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()) {
       List<SnapshotDescription> snapshotDescriptions = admin.listSnapshots();
       boolean isSnapshotPresent = false;
-      if (CollectionUtils.isNotEmpty(snapshotDescriptions)) {
+      if (snapshotDescriptions != null && !snapshotDescriptions.isEmpty()) {
         for (SnapshotDescription snapshotDescription : snapshotDescriptions) {
           if (snapshotName.equals(snapshotDescription.getName())) {
             isSnapshotPresent = true;
@@ -473,38 +477,35 @@ public class TableSnapshotReadsMapReduceIT extends BaseTest {
   }
 
   /**
-   * Making sure that restore temp directory is not having multiple sub directories
-   * for same snapshot restore.
-   * @param conf
-   * @param restoreDir
-   * @param expectedCount
-   * @throws IOException
+   * Making sure that restore temp directory is not having multiple sub directories for same
+   * snapshot restore.
    */
   private void assertRestoreDirCount(Configuration conf, String restoreDir, int expectedCount)
-          throws IOException {
+    throws IOException {
     FileSystem fs = FileSystem.get(conf);
     FileStatus[] subDirectories = fs.listStatus(new Path(restoreDir));
     assertNotNull(subDirectories);
     if (isSnapshotRestoreDoneExternally) {
-      //Snapshot Restore to be deleted externally by the caller
+      // Snapshot Restore to be deleted externally by the caller
       assertEquals(expectedCount, subDirectories.length);
     } else {
-      //Snapshot Restore already deleted internally
+      // Snapshot Restore already deleted internally
       assertEquals(0, subDirectories.length);
     }
   }
 
-  public static class TableSnapshotMapper extends Mapper<NullWritable, PhoenixIndexDBWritable, ImmutableBytesWritable, NullWritable> {
+  public static class TableSnapshotMapper
+    extends Mapper<NullWritable, PhoenixIndexDBWritable, ImmutableBytesWritable, NullWritable> {
 
     @Override
     protected void map(NullWritable key, PhoenixIndexDBWritable record, Context context)
-        throws IOException, InterruptedException {
+      throws IOException, InterruptedException {
       final List<Object> values = record.getValues();
       result.add(values);
 
       // write dummy data
       context.write(new ImmutableBytesWritable(UUID.randomUUID().toString().getBytes()),
-          NullWritable.get());
+        NullWritable.get());
     }
   }
 
