@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -17,25 +17,21 @@
  */
 package org.apache.phoenix.end2end.index;
 
+import java.sql.Connection;
+import java.sql.DriverManager;
+import java.sql.PreparedStatement;
+import java.util.Map;
 import org.apache.phoenix.end2end.NeedsOwnMiniClusterTest;
 import org.apache.phoenix.mapreduce.index.automation.PhoenixAsyncIndex;
 import org.apache.phoenix.mapreduce.index.automation.PhoenixMRJobSubmitter;
 import org.apache.phoenix.query.BaseTest;
-import org.apache.phoenix.schema.MetaDataClient;
 import org.apache.phoenix.schema.PIndexState;
 import org.apache.phoenix.util.ReadOnlyProps;
-import org.apache.phoenix.util.RunUntilFailure;
 import org.apache.phoenix.util.TestUtil;
 import org.junit.Assert;
 import org.junit.BeforeClass;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
-import org.junit.runner.RunWith;
-
-import java.sql.Connection;
-import java.sql.DriverManager;
-import java.sql.PreparedStatement;
-import java.util.Map;
 
 @Category(NeedsOwnMiniClusterTest.class)
 public class PhoenixMRJobSubmitterIT extends BaseTest {
@@ -54,8 +50,10 @@ public class PhoenixMRJobSubmitterIT extends BaseTest {
     String asyncIndexName = "IDX_" + generateUniqueName();
     String needsRebuildIndexName = "IDX_" + generateUniqueName();
     String tableDDL = "CREATE TABLE " + tableName + TestUtil.TEST_TABLE_SCHEMA;
-    String asyncIndexDDL = "CREATE INDEX " + asyncIndexName + " ON " + tableName + " (a.varchar_col1) ASYNC";
-    String needsRebuildIndexDDL = "CREATE INDEX " + needsRebuildIndexName + " ON " + tableName + " (a.char_col1)";
+    String asyncIndexDDL =
+      "CREATE INDEX " + asyncIndexName + " ON " + tableName + " (a.varchar_col1) ASYNC";
+    String needsRebuildIndexDDL =
+      "CREATE INDEX " + needsRebuildIndexName + " ON " + tableName + " (a.char_col1)";
     long rebuildTimestamp = 100L;
 
     createTestTable(getUrl(), tableDDL);
@@ -67,38 +65,40 @@ public class PhoenixMRJobSubmitterIT extends BaseTest {
       conn = DriverManager.getConnection(getUrl());
       TestUtil.assertIndexState(conn, needsRebuildIndexName, PIndexState.ACTIVE, 0L);
 
-      //first make sure that we don't return an active index
+      // first make sure that we don't return an active index
       PhoenixMRJobSubmitter submitter = new PhoenixMRJobSubmitter(getUtility().getConfiguration());
       Map<String, PhoenixAsyncIndex> candidateMap = submitter.getCandidateJobs(conn);
       Assert.assertNotNull(candidateMap);
       Assert.assertEquals(0, candidateMap.size());
 
-      //create an index with ASYNC that will need building via MapReduce
+      // create an index with ASYNC that will need building via MapReduce
       createTestTable(getUrl(), asyncIndexDDL);
       TestUtil.assertIndexState(conn, asyncIndexName, PIndexState.BUILDING, 0L);
 
-      //now force a rebuild on the needsRebuildIndex
-      stmt = conn.prepareStatement(String.format(REQUEST_INDEX_REBUILD_SQL, needsRebuildIndexName, tableName));
+      // now force a rebuild on the needsRebuildIndex
+      stmt = conn.prepareStatement(
+        String.format(REQUEST_INDEX_REBUILD_SQL, needsRebuildIndexName, tableName));
       stmt.execute();
       conn.commit();
       TestUtil.assertIndexState(conn, asyncIndexName, PIndexState.BUILDING, 0L);
 
-      //regenerate the candidateMap. We should get both indexes back this time.
+      // regenerate the candidateMap. We should get both indexes back this time.
       candidateMap = submitter.getCandidateJobs(conn);
       Assert.assertNotNull(candidateMap);
       Assert.assertEquals(2, candidateMap.size());
       boolean foundAsyncIndex = false;
       boolean foundNeedsRebuildIndex = false;
-      for (PhoenixAsyncIndex indexInfo : candidateMap.values()){
-        if (indexInfo.getTableName().equals(asyncIndexName)){
+      for (PhoenixAsyncIndex indexInfo : candidateMap.values()) {
+        if (indexInfo.getTableName().equals(asyncIndexName)) {
           foundAsyncIndex = true;
-        } else if (indexInfo.getTableName().equals(needsRebuildIndexName)){
+        } else if (indexInfo.getTableName().equals(needsRebuildIndexName)) {
           foundNeedsRebuildIndex = true;
         }
       }
       Assert.assertTrue("Did not return index in BUILDING created with ASYNC!", foundAsyncIndex);
-      Assert.assertTrue("Did not return index in REBUILD with an ASYNC_REBUILD_TIMESTAMP!", foundNeedsRebuildIndex);
-    } catch(Exception e) {
+      Assert.assertTrue("Did not return index in REBUILD with an ASYNC_REBUILD_TIMESTAMP!",
+        foundNeedsRebuildIndex);
+    } catch (Exception e) {
       Assert.fail(e.getMessage());
     } finally {
       if (stmt != null) {
