@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -15,7 +15,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.hadoop.hbase.regionserver.wal;
 
 import static org.junit.Assert.assertEquals;
@@ -23,7 +22,6 @@ import static org.junit.Assert.assertEquals;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.List;
-
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FSDataInputStream;
 import org.apache.hadoop.fs.FSDataOutputStream;
@@ -85,9 +83,7 @@ public class ReadWriteKeyValuesWithCodecTest {
     writeReadAndVerify(compression, fs, edits, testFile);
   }
 
-  /**
-   * @return a bunch of {@link WALEdit}s that test a range of serialization possibilities.
-   */
+  /** Returns a bunch of {@link WALEdit}s that test a range of serialization possibilities. */
   private List<WALEdit> getEdits() {
     // Build up a couple of edits
     List<WALEdit> edits = new ArrayList<WALEdit>();
@@ -103,12 +99,12 @@ public class ReadWriteKeyValuesWithCodecTest {
     WALEdit withDelete = new WALEdit();
     addMutation(withDelete, d, FAMILY);
     edits.add(withDelete);
-    
+
     WALEdit withPutsAndDeletes = new WALEdit();
     addMutation(withPutsAndDeletes, d, FAMILY);
     addMutation(withPutsAndDeletes, p, FAMILY);
     edits.add(withPutsAndDeletes);
-    
+
     WALEdit justIndexUpdates = new WALEdit();
     byte[] table = Bytes.toBytes("targetTable");
 
@@ -136,24 +132,24 @@ public class ReadWriteKeyValuesWithCodecTest {
     }
   }
 
-  
-  private void writeWALEdit(WALCellCodec codec, List<Cell> kvs, FSDataOutputStream out) throws IOException {
+  private void writeWALEdit(WALCellCodec codec, List<Cell> kvs, FSDataOutputStream out)
+    throws IOException {
     out.writeInt(kvs.size());
     Codec.Encoder cellEncoder = codec.getEncoder(out);
     // We interleave the two lists for code simplicity
     for (Cell kv : kvs) {
-        cellEncoder.write(kv);
+      cellEncoder.write(kv);
     }
   }
-  
+
   /**
    * Write the edits to the specified path on the {@link FileSystem} using the given codec and then
    * read them back in and ensure that we read the same thing we wrote.
    */
-  private void writeReadAndVerify(final CompressionContext compressionContext, FileSystem fs, List<WALEdit> edits,
-      Path testFile) throws IOException {
-	  
-	WALCellCodec codec = WALCellCodec.create(UTIL.getConfiguration(), compressionContext);  
+  private void writeReadAndVerify(final CompressionContext compressionContext, FileSystem fs,
+    List<WALEdit> edits, Path testFile) throws IOException {
+
+    WALCellCodec codec = WALCellCodec.create(UTIL.getConfiguration(), compressionContext);
     // write the edits out
     FSDataOutputStream out = fs.create(testFile);
     for (WALEdit edit : edits) {
@@ -173,13 +169,14 @@ public class ReadWriteKeyValuesWithCodecTest {
     in.close();
 
     // make sure the read edits match the written
-    for(int i=0; i< edits.size(); i++){
+    for (int i = 0; i < edits.size(); i++) {
       WALEdit expected = edits.get(i);
       WALEdit found = read.get(i);
-      for(int j=0; j< expected.getCells().size(); j++){
+      for (int j = 0; j < expected.getCells().size(); j++) {
         Cell fkv = found.getCells().get(j);
         Cell ekv = expected.getCells().get(j);
-        assertEquals("KV mismatch for edit! Expected: "+expected+", but found: "+found, ekv, fkv);
+        assertEquals("KV mismatch for edit! Expected: " + expected + ", but found: " + found, ekv,
+          fkv);
       }
     }
   }
