@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -17,18 +17,14 @@
  */
 package org.apache.hadoop.metrics2.lib;
 
-import org.apache.hadoop.metrics2.lib.MetricsInfoImpl;
-
 /**
  * Helper class to expose access to the {@link org.apache.hadoop.metrics2.lib.MetricsInfoImpl}
  */
 public class ExposedMetricsInfoImpl extends MetricsInfoImpl {
 
-    /**
-     * @param name
-     * @param description
-     */
-    public ExposedMetricsInfoImpl(String name, String description) {
-        super(name, description);
-    }
-}
\ No newline at end of file
+  /**
+   */
+  public ExposedMetricsInfoImpl(String name, String description) {
+    super(name, description);
+  }
+}
