@@ -7,11 +7,13 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package org.apache.phoenix.cache;
 
@@ -19,7 +21,6 @@ import static org.junit.Assert.assertEquals;
 
 import java.sql.SQLException;
 import java.util.HashMap;
-
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.apache.phoenix.query.ConnectionQueryServices;
@@ -30,23 +31,23 @@ import org.junit.Test;
 import org.mockito.Mockito;
 
 public class ServerCacheClientTest {
-    @Test
-    public void testAddServerCache() throws SQLException {
-        PhoenixConnection connection = Mockito.mock(PhoenixConnection.class);
-        ConnectionQueryServices services = Mockito.mock(ConnectionQueryServices.class);
-        Mockito.when(services.getExecutor()).thenReturn(null);
-        Mockito.when(services.getProps()).thenReturn(new ReadOnlyProps(new HashMap<>()));
-        Mockito.when(connection.getQueryServices()).thenReturn(services);
-        byte[] tableName = Bytes.toBytes("TableName");
-        PTableImpl pTable =  Mockito.mock(PTableImpl.class);
-        Mockito.when(pTable.getPhysicalName()).thenReturn(PNameFactory.newName("TableName"));
-        Mockito.when(services.getAllTableRegions(tableName, 600000)).thenThrow(new SQLException(
-                "Test Exception"));
-        ServerCacheClient client = new ServerCacheClient(connection);
-        try {
-            client.addServerCache(null, null, null, null, pTable, false);
-        } catch (Exception e) {
-            assertEquals(e.getMessage(), "Test Exception");
-        }
+  @Test
+  public void testAddServerCache() throws SQLException {
+    PhoenixConnection connection = Mockito.mock(PhoenixConnection.class);
+    ConnectionQueryServices services = Mockito.mock(ConnectionQueryServices.class);
+    Mockito.when(services.getExecutor()).thenReturn(null);
+    Mockito.when(services.getProps()).thenReturn(new ReadOnlyProps(new HashMap<>()));
+    Mockito.when(connection.getQueryServices()).thenReturn(services);
+    byte[] tableName = Bytes.toBytes("TableName");
+    PTableImpl pTable = Mockito.mock(PTableImpl.class);
+    Mockito.when(pTable.getPhysicalName()).thenReturn(PNameFactory.newName("TableName"));
+    Mockito.when(services.getAllTableRegions(tableName, 600000))
+      .thenThrow(new SQLException("Test Exception"));
+    ServerCacheClient client = new ServerCacheClient(connection);
+    try {
+      client.addServerCache(null, null, null, null, pTable, false);
+    } catch (Exception e) {
+      assertEquals(e.getMessage(), "Test Exception");
     }
+  }
 }
