@@ -1,9 +1,25 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 package org.apache.phoenix.metrics;
 
 import static org.junit.Assert.fail;
 
 import java.util.Map;
-
 import org.apache.phoenix.monitoring.MetricType;
 import org.junit.Test;
 
@@ -28,15 +44,16 @@ import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
  */
 public class MetricTypeTest {
 
-	@Test
-    public void testUniqueShortNames() throws Exception {
-		Map<String, MetricType> shortNameMap = Maps.newHashMapWithExpectedSize(MetricType.values().length);
-        for (MetricType type : MetricType.values()) {
-        	MetricType oldMetricType = shortNameMap.put(type.shortName(), type);
-        	if (oldMetricType!=null) {
-				fail("Metric short names should be unique found duplicates for " + type.name() + " and "
-						+ oldMetricType.name());
-        	}
-        }
+  @Test
+  public void testUniqueShortNames() throws Exception {
+    Map<String, MetricType> shortNameMap =
+      Maps.newHashMapWithExpectedSize(MetricType.values().length);
+    for (MetricType type : MetricType.values()) {
+      MetricType oldMetricType = shortNameMap.put(type.shortName(), type);
+      if (oldMetricType != null) {
+        fail("Metric short names should be unique found duplicates for " + type.name() + " and "
+          + oldMetricType.name());
+      }
     }
+  }
 }
