@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,21 +18,23 @@
 package org.apache.phoenix.transaction;
 
 import java.sql.SQLException;
-
 import org.apache.hadoop.conf.Configuration;
 import org.apache.phoenix.jdbc.ConnectionInfo;
 import org.apache.phoenix.transaction.TransactionFactory.Provider;
 
 public class TransactionServiceManager {
 
-    public static PhoenixTransactionService startTransactionService(TransactionFactory.Provider provider, Configuration config, ConnectionInfo connInfo, int port) throws SQLException {
-        PhoenixTransactionProvider transactionProvider = provider.getTransactionProvider();
-        if (provider == Provider.NOTAVAILABLE) {
-            return NotAvailableTransactionService.getInstance();
-        } else if (provider == Provider.OMID) {
-            return OmidTransactionService.startAndInjectOmidTransactionService((OmidTransactionProvider)transactionProvider, config, connInfo, port);
-        }
-        throw new UnsupportedOperationException("Unknown transaction provider");
+  public static PhoenixTransactionService startTransactionService(
+    TransactionFactory.Provider provider, Configuration config, ConnectionInfo connInfo, int port)
+    throws SQLException {
+    PhoenixTransactionProvider transactionProvider = provider.getTransactionProvider();
+    if (provider == Provider.NOTAVAILABLE) {
+      return NotAvailableTransactionService.getInstance();
+    } else if (provider == Provider.OMID) {
+      return OmidTransactionService.startAndInjectOmidTransactionService(
+        (OmidTransactionProvider) transactionProvider, config, connInfo, port);
     }
+    throw new UnsupportedOperationException("Unknown transaction provider");
+  }
 
-}
\ No newline at end of file
+}
