@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -21,7 +21,6 @@ import java.io.IOException;
 import java.sql.Connection;
 import java.sql.SQLException;
 import java.util.List;
-
 import org.apache.commons.csv.CSVFormat;
 import org.apache.commons.csv.CSVParser;
 import org.apache.commons.csv.CSVRecord;
@@ -34,42 +33,41 @@ import org.apache.phoenix.thirdparty.com.google.common.collect.Iterables;
 
 public class CsvUpsertExecutorTest extends AbstractUpsertExecutorTest<CSVRecord, String> {
 
-    private static final String ARRAY_SEP = ":";
+  private static final String ARRAY_SEP = ":";
 
-    private UpsertExecutor<CSVRecord, String> upsertExecutor;
+  private UpsertExecutor<CSVRecord, String> upsertExecutor;
 
-    @Override
-    public UpsertExecutor<CSVRecord, String> getUpsertExecutor() {
-        return upsertExecutor;
-    }
-    
-    @Override
-    public UpsertExecutor<CSVRecord, String> getUpsertExecutor(Connection conn) {
-        return new CsvUpsertExecutor(conn, columnInfoList, preparedStatement,
-                upsertListener, ARRAY_SEP);
-    }
-    
-    @Override
-    public CSVRecord createRecord(Object... columnValues) throws IOException {
-        for (int i = 0; i < columnValues.length; i++) {
-            if (columnValues[i] == null) {
-                // Joiner.join throws on nulls, replace with empty string.
-                columnValues[i] = "";
-            }
-            if (columnValues[i] instanceof List) {
-                columnValues[i] = Joiner.on(ARRAY_SEP).join((List<?>) columnValues[i]);
-            }
-        }
-        String inputRecord = Joiner.on(',').join(columnValues);
-        return Iterables.getFirst(CSVParser.parse(inputRecord, CSVFormat.DEFAULT), null);
-    }
+  @Override
+  public UpsertExecutor<CSVRecord, String> getUpsertExecutor() {
+    return upsertExecutor;
+  }
 
-    @Before
-    public void setUp() throws SQLException {
-        super.setUp();
-        upsertExecutor = new CsvUpsertExecutor(conn, columnInfoList, preparedStatement,
-                upsertListener, ARRAY_SEP);
+  @Override
+  public UpsertExecutor<CSVRecord, String> getUpsertExecutor(Connection conn) {
+    return new CsvUpsertExecutor(conn, columnInfoList, preparedStatement, upsertListener,
+      ARRAY_SEP);
+  }
+
+  @Override
+  public CSVRecord createRecord(Object... columnValues) throws IOException {
+    for (int i = 0; i < columnValues.length; i++) {
+      if (columnValues[i] == null) {
+        // Joiner.join throws on nulls, replace with empty string.
+        columnValues[i] = "";
+      }
+      if (columnValues[i] instanceof List) {
+        columnValues[i] = Joiner.on(ARRAY_SEP).join((List<?>) columnValues[i]);
+      }
     }
+    String inputRecord = Joiner.on(',').join(columnValues);
+    return Iterables.getFirst(CSVParser.parse(inputRecord, CSVFormat.DEFAULT), null);
+  }
+
+  @Before
+  public void setUp() throws SQLException {
+    super.setUp();
+    upsertExecutor =
+      new CsvUpsertExecutor(conn, columnInfoList, preparedStatement, upsertListener, ARRAY_SEP);
+  }
 
-    
 }
