@@ -19,7 +19,8 @@ CREATE TABLE IF NOT EXISTS PHERF.TEST_TABLE (
     TENANT_ID CHAR(15) NOT NULL,
     PARENT_ID CHAR(15) NOT NULL,
     CREATED_DATE DATE NOT NULL,
-    NOW_DATE DATE,
+    SOME_DATE DATE,
+    RND_DATE DATE,
     TS_DATE TIMESTAMP,
     PRESENT_DATE DATE,
     OTHER_ID CHAR(15),
@@ -29,6 +30,7 @@ CREATE TABLE IF NOT EXISTS PHERF.TEST_TABLE (
     DIVISION INTEGER,
     OLDVAL_STRING VARCHAR,
     NEWVAL_STRING VARCHAR,
+    CONNECTION_ID VARCHAR,
     SOME_INT INTEGER
     CONSTRAINT PK PRIMARY KEY
     (
